package WebGUI::i18n::German::Shop;
use utf8;
our $I18N = {
  'Add new address' => {
    'lastUpdated' => '1273049137',
    'message' => 'Neue Adresse hinzufügen'
  },
  'Backordered' => {
    'lastUpdated' => '1241614989',
    'message' => 'Lieferrückstand'
  },
  'Billing Address' => {
    'lastUpdated' => '1273049151',
    'message' => 'Rechnungsanschrift'
  },
  'Cancelled' => {
    'lastUpdated' => '1228748625',
    'message' => 'Storniert'
  },
  'Choose a payment gateway and update the cart to checkout' => {
    'lastUpdated' => '1273649689',
    'message' => 'Wählen Sie eine Zahlungsart und aktualisieren den Warenkorb um zu bezahlen.'
  },
  'Choose a payment method' => {
    'lastUpdated' => '1273049180',
    'message' => 'Wählen Sie eine Zahlungsart'
  },
  'Choose a shipping method' => {
    'lastUpdated' => '1254901242',
    'message' => 'Wählen Sie eine Versandart.'
  },
  'Choose a shipping method and update the cart to checkout' => {
    'lastUpdated' => '1254901286',
    'message' => 'Wählen Sie eine Versandart und aktualisieren Sie den Warenkorb um zu bezahlen.'
  },
  'Failed' => {
    'lastUpdated' => '1256112658',
    'message' => 'Fehler'
  },
  'No shippers' => {
    'lastUpdated' => '1251893840',
    'message' => 'Es sind keine Versandtreiber konfiguriert. Benutzer können nicht bezahlen, bevor nicht mindestens einer konfiguriert ist.'
  },
  'No shipping plugins configured' => {
    'lastUpdated' => '1251896456',
    'message' => 'Es sind keine Versand-Plugins konfiguriert. Bitte informieren Sie den Shopbetreiber.'
  },
  'NotShipped' => {
    'lastUpdated' => '1241298317',
    'message' => 'Nicht ausgeliefert'
  },
  'Payment Information' => {
    'lastUpdated' => '1241615121',
    'message' => 'Zahlungs-Informationen'
  },
  'Preferred Payment Type' => {
    'lastUpdated' => '1228748672',
    'message' => 'Bevorzugte Zahlungsart'
  },
  'Shipped' => {
    'lastUpdated' => '1241298331',
    'message' => 'Ausgeliefert'
  },
  'Shipping Address' => {
    'lastUpdated' => '1273049190',
    'message' => 'Versandadresse'
  },
  'Special shipping' => {
    'lastUpdated' => '1273049210',
    'message' => 'Versanddetails'
  },
  'Status' => {
    'lastUpdated' => '1256112676',
    'message' => 'Status'
  },
  'Success' => {
    'lastUpdated' => '1256112683',
    'message' => 'Erfolg'
  },
  'Update %s' => {
    'lastUpdated' => '1273649715',
    'message' => 'Aktualisiere Adresse: %s'
  },
  'Update this address' => {
    'lastUpdated' => '1273049227',
    'message' => 'Diese Adresse akutalisieren'
  },
  'add a new address' => {
    'lastUpdated' => '1228748699',
    'message' => 'Eine neue Adresse hinzufügen'
  },
  'add a vendor' => {
    'lastUpdated' => '1228748732',
    'message' => 'Einen Anbieter hinzufügen'
  },
  'add credit message' => {
    'lastUpdated' => '1241166791',
    'message' => '%s wurde dem Guthabenkonto von %s hinzugefügt. Das Gesamtguthaben beträgt %s'
  },
  'add payment method' => {
    'lastUpdated' => '1228748766',
    'message' => 'Eine Zahlungsart hinzufügen'
  },
  'add shipper' => {
    'lastUpdated' => '1228748793',
    'message' => 'Eine Versandart hinzufügen'
  },
  'add to cart' => {
    'lastUpdated' => '1228748807',
    'message' => 'In den Warenkorb legen'
  },
  'addButton help' => {
    'lastUpdated' => '1228748835',
    'message' => 'Ein Button, mit dem der Benutzer eine neue Adresse hinzufügen kann.'
  },
  'address' => {
    'lastUpdated' => '1228748842',
    'message' => 'Adresse'
  },
  'address book template' => {
    'lastUpdated' => '1228748854',
    'message' => 'Adressbuch-Vorlage'
  },
  'address book template help' => {
    'lastUpdated' => '1228748877',
    'message' => 'Diese Vorlage legt das Aussehen des Adressbuches fest'
  },
  'address help' => {
    'lastUpdated' => '1228748896',
    'message' => 'Eine HTML-formatierte Adresse'
  },
  'address labelField help' => {
    'lastUpdated' => '1228748973',
    'message' => 'Ein Feld, das die Adressebezeichnung enthält. Beispiele: Heimatanschrift oder Arbeit'
  },
  'address loop help' => {
    'lastUpdated' => '1228749055',
    'message' => 'Eine schleife, die die Liste der Adressen dieses Adressbuches und die Bearbeitungsmöglichkeiten enthält'
  },
  'address nameField help' => {
    'lastUpdated' => '1228749090',
    'message' => 'Ein Feld, das den Namen der Person/Firma für diese Adresse enthält.'
  },
  'address1 help' => {
    'lastUpdated' => '1228749103',
    'message' => 'Die erste Adresszeile'
  },
  'address1Field help' => {
    'lastUpdated' => '1228749545',
    'message' => 'Das Feld für die erste Adresszeile'
  },
  'address2 help' => {
    'lastUpdated' => '1228749116',
    'message' => 'Die zweite Adresszeile'
  },
  'address2Field help' => {
    'lastUpdated' => '1228749558',
    'message' => 'Das Feld für die zweite Adreszeile'
  },
  'address3 help' => {
    'lastUpdated' => '1228749127',
    'message' => 'Die dritte Adresszeile'
  },
  'address3Field help' => {
    'lastUpdated' => '1228749572',
    'message' => 'Das Feld für die dritte Adresszeile'
  },
  'addresses loop help' => {
    'lastUpdated' => '1228749592',
    'message' => 'Eine Schleife, die alle Adressen dieses Adressbuches enthält'
  },
  'amount' => {
    'lastUpdated' => '1228174754',
    'message' => 'Betrag'
  },
  'amount help' => {
    'lastUpdated' => '1228749627',
    'message' => 'Der Gesamtbetrag dieser Transaktion, formatiert mit zwei Nachkommastellen.'
  },
  'available' => {
    'lastUpdated' => '1228749136',
    'message' => 'Verfügbar'
  },
  'billing address1' => {
    'lastUpdated' => '1273649756',
    'message' => 'Bitte geben Sie eine Straße für die Rechnungsadresse an.'
  },
  'billing city' => {
    'lastUpdated' => '1273649770',
    'message' => 'Bitte geben Sie einen Ort für die Rechnungsadresse an.'
  },
  'billing code' => {
    'lastUpdated' => '1273649784',
    'message' => 'Bitte geben Sie eine Postleitzahl für die Rechnungsadresse an.'
  },
  'billing country' => {
    'lastUpdated' => '1273649795',
    'message' => 'Bitte geben Sie einen Land für die Rechnungsadresse an.'
  },
  'billing firstName' => {
    'lastUpdated' => '1273649808',
    'message' => 'Bitte geben Sie den Vornamen für die Rechnungsadresse an.'
  },
  'billing label' => {
    'lastUpdated' => '1273649825',
    'message' => 'Bitte geben Sie eine Bezeichnung für die Rechnungsadresse an.'
  },
  'billing lastName' => {
    'lastUpdated' => '1273649837',
    'message' => 'Bitte geben Sie einen Nachnamen für die Rechnungsadresse an.'
  },
  'billing phoneNumber' => {
    'lastUpdated' => '1273649850',
    'message' => 'Bitte geben Sie eine Telefonnummer für die Rechnungsadresse an.'
  },
  'billing state' => {
    'lastUpdated' => '1273649880',
    'message' => 'Bitte geben Sie Bundesland/Bezirk für die Rechnungsadresse an.'
  },
  'billingAddressChooser help' => {
    'lastUpdated' => '1278344752',
    'message' => 'Eine Dropdown-Auswahlliste zur Auswahl der Standardrechnungsadresse.'
  },
  'biweekly' => {
    'lastUpdated' => '1228749149',
    'message' => 'Zwei Wochen'
  },
  'cancel recurring transaction' => {
    'lastUpdated' => '1228749671',
    'message' => 'Wiederkehrende Transaktion abbrechen'
  },
  'cancelRecurringUrl' => {
    'lastUpdated' => '1228749700',
    'message' => 'Ein URL, mit dem der Bentuzer eine wiederkehrende Transaktion abbrechen kann.'
  },
  'cart checkout minimum' => {
    'lastUpdated' => '1240756405',
    'message' => 'Minimum Bestellwert'
  },
  'cart checkout minimum help' => {
    'lastUpdated' => '1240756423',
    'message' => 'Verwenden Sie diese Einstellung um einen Minimumbestellwert festzulegen.'
  },
  'cart template' => {
    'lastUpdated' => '1228749715',
    'message' => 'Warenkorb-Vorlage'
  },
  'cart template help' => {
    'lastUpdated' => '1228749735',
    'message' => 'Diese Vorlage bestimmt, wie der Warenkorb dargestellt wird.'
  },
  'cashier' => {
    'lastUpdated' => '1241615467',
    'message' => 'Kassierer'
  },
  'checkout button' => {
    'lastUpdated' => '1228749778',
    'message' => 'Zur Kasse'
  },
  'checkoutButton help' => {
    'lastUpdated' => '1228749830',
    'message' => 'Der Button, den der Benutzer anklicken muss, um zur Auswahl der Bezahlungsmethode zu gelangen.'
  },
  'choose payment gateway message' => {
    'lastUpdated' => '1228749841',
    'message' => 'Wie möchten Sie bezahlen?'
  },
  'choose shipping button' => {
    'lastUpdated' => '1228749871',
    'message' => 'Wählen Sie Adresse und Bezahlung.'
  },
  'chooseShippingButton help' => {
    'lastUpdated' => '1228749909',
    'message' => 'Anklicken dieses Buttons führt den Benutzer zur Auswahl einer Versandadresse aus dem Adressbuch.'
  },
  'city' => {
    'lastUpdated' => '1243496413',
    'message' => 'Ort'
  },
  'city help' => {
    'lastUpdated' => '1243496641',
    'message' => 'Der Ort zu dieser Adresse'
  },
  'cityField help' => {
    'lastUpdated' => '1243496615',
    'message' => 'Ein Feld, das den Ort zur Adresse enthält'
  },
  'code' => {
    'lastUpdated' => '1228749956',
    'message' => 'Postleitzahl'
  },
  'code help' => {
    'lastUpdated' => '1228749973',
    'message' => 'Die Postleitzahl dieser Adresse'
  },
  'codeField help' => {
    'lastUpdated' => '1228750069',
    'message' => 'Ein Feld, das die Postleitzahl zu dieser Adresse enthält'
  },
  'company url' => {
    'lastUpdated' => '1228750080',
    'message' => 'Firmen-URL'
  },
  'configuredTitle' => {
    'lastUpdated' => '1241156746',
    'message' => 'Titel für die Asset-ID. Dies ist ein vom Benutzer angepasster Titel für das Asset.'
  },
  'configuredTitle help' => {
    'lastUpdated' => '1241159025',
    'message' => 'Name des Artikels, sowie für den Kauf konfiguriert'
  },
  'continue shopping button' => {
    'lastUpdated' => '1240756452',
    'message' => 'Weiter einkaufen'
  },
  'continueShoppingButton help' => {
    'lastUpdated' => '1241157767',
    'message' => 'Wenn dieser Knopf aktiviert wird, wird der Benutzer zurück zur Website geführt.'
  },
  'copy from home address' => {
    'lastUpdated' => '1242498322',
    'message' => 'Private Adresse übernehmen'
  },
  'copy from work address' => {
    'lastUpdated' => '1242498308',
    'message' => 'Firmenadresse übernehmen'
  },
  'country' => {
    'lastUpdated' => '1240755709',
    'message' => 'Land'
  },
  'country help' => {
    'lastUpdated' => '1241156769',
    'message' => 'Das Land zu dieser Adresse'
  },
  'countryField help' => {
    'lastUpdated' => '1241156807',
    'message' => 'Ein Feld für das Land zu dieser Adresse.'
  },
  'coupon' => {
    'lastUpdated' => '1240756464',
    'message' => 'Coupon'
  },
  'current credit message' => {
    'lastUpdated' => '1273649900',
    'message' => '%s hat einen Gesamtkredit über %s.'
  },
  'date' => {
    'lastUpdated' => '1228174772',
    'message' => '<p>Datum&nbsp;</p>'
  },
  'date created' => {
    'lastUpdated' => '1240496089',
    'message' => 'Erstellungsdatum'
  },
  'dateAdded help' => {
    'lastUpdated' => '1241156869',
    'message' => 'Datum und Zeit als dieses Item in den Warenkorb gelegt wurde.'
  },
  'dateOfPurchase' => {
    'lastUpdated' => '1240756475',
    'message' => 'Bestelldatum'
  },
  'default' => {
    'lastUpdated' => '1241157794',
    'message' => 'Standardeinstellung'
  },
  'defaultButton help' => {
    'lastUpdated' => '1241157847',
    'message' => 'Ein Knopf, der es dem Benutzer ermöglicht, eine Adresse als Standardeinstellung zu verwenden.'
  },
  'delete' => {
    'lastUpdated' => '1240781527',
    'message' => 'Löschen'
  },
  'deleteButton help' => {
    'lastUpdated' => '1241159076',
    'message' => 'Ein Knopf, der es dem Benutzer ermöglicht, eine bestehende Adresse zu löschen.'
  },
  'deschedule all button' => {
    'lastUpdated' => '1242498471',
    'message' => 'Alle Terminierungen aufheben.'
  },
  'edit' => {
    'lastUpdated' => '1240756484',
    'message' => 'Ändern'
  },
  'edit address template' => {
    'lastUpdated' => '1241156898',
    'message' => 'Adressänderungsvorlage'
  },
  'edit address template help' => {
    'lastUpdated' => '1241159126',
    'message' => 'Vorlage für den Adressen-Editor'
  },
  'editButton help' => {
    'lastUpdated' => '1241157092',
    'message' => 'Ein Knopf, der dem Benutzer ermöglicht eine bestehende Adresse zu ändern.'
  },
  'email' => {
    'lastUpdated' => '1228749164',
    'message' => 'E-Mail'
  },
  'emailField help' => {
    'lastUpdated' => '1278344792',
    'message' => 'Ein Feld, das die E-Mail-Adresse zu dieser Adresse enthält.'
  },
  'empty cart' => {
    'lastUpdated' => '1240755736',
    'message' => 'Ihr Warenkorb ist leer'
  },
  'error help' => {
    'lastUpdated' => '1241157126',
    'message' => 'Wenn es Probleme gibt, wird die Fehlermeldung hier angegeben.'
  },
  'export tax' => {
    'lastUpdated' => '1240756505',
    'message' => 'Exportsteuer'
  },
  'extended price' => {
    'lastUpdated' => '1240781512',
    'message' => 'Preis * Menge'
  },
  'extendedPrice help' => {
    'lastUpdated' => '1241156940',
    'message' => 'Preis der Auftragsposition (Menge*Stückzahl)'
  },
  'firstName' => {
    'lastUpdated' => '1228749171',
    'message' => 'Vorname'
  },
  'formFooter help' => {
    'lastUpdated' => '1241156957',
    'message' => 'Abschluss des Formulars'
  },
  'formHeader help' => {
    'lastUpdated' => '1241156973',
    'message' => 'Formularkopf'
  },
  'fourweekly' => {
    'lastUpdated' => '1240758758',
    'message' => 'Vierwöchentlich'
  },
  'group label' => {
    'lastUpdated' => '1243114783',
    'message' => 'Bezeichnung'
  },
  'group rate' => {
    'lastUpdated' => '1243114800',
    'message' => 'MwSt-Satz'
  },
  'halfyearly' => {
    'lastUpdated' => '1240757947',
    'message' => 'halbjählich'
  },
  'hasShippingAddress help' => {
    'lastUpdated' => '1241298388',
    'message' => 'Angabe, ob der Benutzer bereits eine Versandadresse angegeben hat. Diese Versandadresse ist immer notwendig um die Steuer errechnen zu können.'
  },
  'hasSku' => {
    'lastUpdated' => '1303289636',
    'message' => 'Ein boolscher Wert, der wahr ist, wenn das Asset, auf das sich dieser Artikel bezieht, noch in WebGUI enthalten ist. Ist diese Variable \'false\', dann sollte <strong>viewItemURL</strong> nicht genutzt werden'
  },
  'import tax' => {
    'lastUpdated' => '1240756543',
    'message' => 'Importsteuer'
  },
  'in shop credit' => {
    'lastUpdated' => '1240756573',
    'message' => 'In-Shop Guthaben'
  },
  'in shop credit used' => {
    'lastUpdated' => '1240756652',
    'message' => 'Verwendetes In-Shop Guthaben'
  },
  'inShopCreditAvailable help' => {
    'lastUpdated' => '1240756627',
    'message' => 'Das In-Shop Guthaben des Benutzers'
  },
  'inShopCreditDeduction help' => {
    'lastUpdated' => '1240781572',
    'message' => 'Guthabenabzug bei dieser Bestellung'
  },
  'is a required field' => {
    'lastUpdated' => '1240756696',
    'message' => '%s soll angegeben werden'
  },
  'isCashier' => {
    'lastUpdated' => '1240758879',
    'message' => 'Angabe, ob der aktuelle Benutzer als Einskaufsvertreter auftreten kann.'
  },
  'isRecurring' => {
    'lastUpdated' => '1240756783',
    'message' => 'Angabe, ob es sich um eine sich wiederholenden Transaktion handelt.'
  },
  'isShippable help' => {
    'lastUpdated' => '1241159170',
    'message' => 'Angabe, ob dem Artikel eine Versandadresse hinzugefügt werden kann.'
  },
  'isSuccessful' => {
    'lastUpdated' => '1240758956',
    'message' => 'Transaktion erfolgreich'
  },
  'isUnique help' => {
    'lastUpdated' => '1241190128',
    'message' => 'Angabe ob dieses Item nur einmal vorkommt und deswegen die maximum Menge 1 beträgt. '
  },
  'item' => {
    'lastUpdated' => '1240496116',
    'message' => 'Artikel'
  },
  'item assetId' => {
    'lastUpdated' => '1240756823',
    'message' => 'Die Asset-ID für diesen Artikel.'
  },
  'item extendedPricePlusTax help' => {
    'lastUpdated' => '1279222176',
    'message' => 'Steuer plus Preis für diesen Artikel multipliziert mit seiner Menge im Warenkorb. Diese Variable steht nur zur Verfügung, wenn der aktuelle Benutzer nicht \'Besucher\' ist.'
  },
  'item lastUpdated' => {
    'lastUpdated' => '1240781617',
    'message' => 'Datum letzter Änderung Transaktionsitem'
  },
  'item name help' => {
    'lastUpdated' => '1241190161',
    'message' => 'Produktname'
  },
  'item options' => {
    'lastUpdated' => '1241157196',
    'message' => 'JSON-kodierte Optionen für dieses Asset. Sie sollten diese Variable wahrscheinlich kaum benötigen.'
  },
  'item price' => {
    'lastUpdated' => '1240755758',
    'message' => 'Artikelpreis'
  },
  'item pricePlusTax help' => {
    'lastUpdated' => '1279222216',
    'message' => 'Steuer plus Preis für diesen Artikel. Diese Variable steht nur zur Verfügung, wenn der aktuelle Benutzer nicht \'Besucher\' ist.'
  },
  'item quantity' => {
    'lastUpdated' => '1240758930',
    'message' => 'Artikelmenge'
  },
  'item shipToButton help' => {
    'lastUpdated' => '1241190697',
    'message' => 'Anklicken dieses Knopfes stellt eine alternative Adresse für dieses Item ein.'
  },
  'item shippingAddress1' => {
    'lastUpdated' => '1241157294',
    'message' => '1. Zeile einer Versandadresse mit mehreren Zeilen'
  },
  'item shippingAddress2' => {
    'lastUpdated' => '1241157274',
    'message' => '2. Zeile einer Versandadresse mit mehreren Zeilen'
  },
  'item shippingAddress3' => {
    'lastUpdated' => '1241157283',
    'message' => '3. Zeile einer Versandadresse mit mehreren Zeilen'
  },
  'item shippingAddressCity' => {
    'lastUpdated' => '1241157902',
    'message' => 'Ort Versandadresse'
  },
  'item shippingAddressCode' => {
    'lastUpdated' => '1241157916',
    'message' => 'Code Versandadresse'
  },
  'item shippingAddressCountry' => {
    'lastUpdated' => '1241157929',
    'message' => 'Land Versandadresse'
  },
  'item shippingAddressId' => {
    'lastUpdated' => '1241157945',
    'message' => 'ID Versandadresse'
  },
  'item shippingAddressPhoneNumber' => {
    'lastUpdated' => '1241167517',
    'message' => 'Telefonnummer zur Versandadresse'
  },
  'item shippingAddressState' => {
    'lastUpdated' => '1241158096',
    'message' => 'Bundesland Versandadresse'
  },
  'item shippingName' => {
    'lastUpdated' => '1241158116',
    'message' => 'Name Versandadresse für dieses Item'
  },
  'item sku deleted' => {
    'lastUpdated' => '1303289660',
    'message' => 'Das Asset zu diesem Artikel kann nicht instantiiert werden.'
  },
  'item taxAmount help' => {
    'lastUpdated' => '1279222235',
    'message' => 'Steuer für diesen Artikel. Diese Variable steht nur zur Verfügung, wenn der aktuelle Benutzer nicht \'Besucher\' ist.'
  },
  'item taxRate help' => {
    'lastUpdated' => '1279222254',
    'message' => 'Steuersatz für diesen Artikel. Diese Variable steht nur zur Verfügung, wenn der aktuelle Benutzer nicht \'Besucher\' ist.'
  },
  'item transactionId' => {
    'lastUpdated' => '1241157961',
    'message' => 'ID Transaktion'
  },
  'item url help' => {
    'lastUpdated' => '1241158163',
    'message' => 'URL zu diesem Item, wie konfiguriert'
  },
  'item vendorId' => {
    'lastUpdated' => '1241157332',
    'message' => 'Die ID des Verkäufers dieses Items'
  },
  'itemAddressChooser help' => {
    'lastUpdated' => '1278344908',
    'message' => 'Eine Dropdown-Auswahlliste zur Wahl der Versandadresse eines einzelnen Produktes im Warenkorb, ermöglicht durch Pro-Produkt-Versand.'
  },
  'itemId' => {
    'lastUpdated' => '1241158021',
    'message' => 'Die eindeutige ID für dieses Item aus allen Items in allen Transaktionen'
  },
  'itemShippingAddress' => {
    'lastUpdated' => '1241158070',
    'message' => 'Formatierte Versandadresse '
  },
  'items' => {
    'lastUpdated' => '1240758723',
    'message' => 'Eine Schleife mit allen Artikeln zu dieser Transaktion'
  },
  'items loop help' => {
    'lastUpdated' => '1241190465',
    'message' => 'Eine Schleife mit den Variablen aller Artikel im Warenkorb'
  },
  'label' => {
    'lastUpdated' => '1242498401',
    'message' => 'Bezeichnung'
  },
  'label help' => {
    'lastUpdated' => '1241190192',
    'message' => 'z.B. "Privat" oder "Firma"'
  },
  'lastName' => {
    'lastUpdated' => '1228749186',
    'message' => 'Nachname'
  },
  'login message' => {
    'lastUpdated' => '1241159336',
    'message' => 'Sie müssen sich <a href="%s">anmelden</a> um den Einkauf tätigen zu können.
'
  },
  'loginFormButton help' => {
    'lastUpdated' => '1278535802',
    'message' => 'Das Ende des Formulars das dem Benutzer beim Login hilft. Diese Variable steht nur zur Verfügung, falls der aktuelle Benutzer Besucher ist.'
  },
  'loginFormFooter help' => {
    'lastUpdated' => '1278535775',
    'message' => 'Das Ende des Formulars das dem Benutzer beim Login hilft. Diese Variable steht nur zur Verfügung, falls der aktuelle Benutzer Besucher ist.'
  },
  'loginFormHeader help' => {
    'lastUpdated' => '1278535758',
    'message' => 'Der Anfang des Formulars das dem Benutzer beim Login hilft. Diese Variable steht nur zur Verfügung, falls der aktuelle Benutzer Besucher ist.'
  },
  'loginFormPassword help' => {
    'lastUpdated' => '1278535661',
    'message' => 'Eine Textbox mit der die Benutzer ihr Passwort verdeckt eingeben. Die Variable steht nur zur Verfügung, falls der aktuelle Benutzer Besucher ist.'
  },
  'loginFormUsername help' => {
    'lastUpdated' => '1278535599',
    'message' => 'Eine Textbox mit der die Benutzer ihren Namen eingeben. Die Variable steht nur zur Verfügung, falls der aktuelle Benutzer Besucher ist.'
  },
  'manage' => {
    'lastUpdated' => '1240758683',
    'message' => 'Verwalten'
  },
  'manage my purchases template' => {
    'lastUpdated' => '1241166899',
    'message' => 'Vorlage "Meine Einkäufe"'
  },
  'manage my purchases template help' => {
    'lastUpdated' => '1241190631',
    'message' => 'DIese Vorlage zeigt Teilinformationen zu den Transaktionen des benutzers an.'
  },
  'message help' => {
    'lastUpdated' => '1278344956',
    'message' => 'Wenn der Warenkorb leer ist wir dem Benutzer diese internationalisierte Meldung angezeigt.'
  },
  'minicart template' => {
    'lastUpdated' => '1240781660',
    'message' => 'Warenkorb Vorlage'
  },
  'minicart template help' => {
    'lastUpdated' => '1241190295',
    'message' => 'Die folgenden Variablen sind in der Vorlage zum Warenkorb vorhanden.'
  },
  'minimumCartAmount help' => {
    'lastUpdated' => '1278345032',
    'message' => 'Der minimale Warenkorbwert aus den Einstellungen mit formatiert mit zwei Nachkommastellen.'
  },
  'mixed items warning' => {
    'lastUpdated' => '1241157671',
    'message' => 'Sie können leider keine Artikel mit und Artikel ohne Verlängerungsoption in Ihren Warenkorb aufnehmen und bezahlen.

Entweder wählen Sie bitte einen Artikel mit Verlängerungsmöglichkeit oder eine beliebige Anzahl sonstiger Artikel. Wenn Sie beide Artikelarten kaufen möchten, tun Sie das bitte durch zwei Bestellvorgänge.'
  },
  'monthly' => {
    'lastUpdated' => '1240758639',
    'message' => 'Monat'
  },
  'my purchases' => {
    'lastUpdated' => '1240758657',
    'message' => 'Meine Einkäufe'
  },
  'my purchases detail template' => {
    'lastUpdated' => '1241190342',
    'message' => 'Vorlage zur detaillierter Darstellung der Einkäufe'
  },
  'my purchases detail template help' => {
    'lastUpdated' => '1241190590',
    'message' => 'Welche Vorlage ist zu verwenden für eine detaillierte Übersicht der Bestellungen eines Benutzers?
Eine Liste mit jeder einzelnen Transaktion statt der komplette Transaktionsliste. '
  },
  'my purchases template' => {
    'lastUpdated' => '1241190366',
    'message' => 'Vorlage "Meine Einkäufe"'
  },
  'my purchases template help' => {
    'lastUpdated' => '1241190416',
    'message' => 'Welche Vorlage soll verwendet werden für die Übersicht der Bestellungen eines Benutzers?'
  },
  'name' => {
    'lastUpdated' => '1228749193',
    'message' => 'Name'
  },
  'name help' => {
    'lastUpdated' => '1241190235',
    'message' => 'Name Ansprechpartner zu dieser Adresse'
  },
  'no billing address' => {
    'lastUpdated' => '1273649936',
    'message' => 'Bitte geben Sie eine Rechnungsadresse an oder wählen eine der gespeicherten aus.'
  },
  'no shipping address' => {
    'lastUpdated' => '1273649972',
    'message' => 'Bitte geben Sie eine Versandadresse an oder wählen eine der gespeicherten aus.'
  },
  'not applicable' => {
    'lastUpdated' => '1240758618',
    'message' => 'entfällt'
  },
  'not scheduled payout amount' => {
    'lastUpdated' => '1242498381',
    'message' => 'Auszahlung nicht terminiert'
  },
  'notes' => {
    'lastUpdated' => '1240755833',
    'message' => 'Notizen zu dieser Transaktion'
  },
  'notice' => {
    'lastUpdated' => '1241166947',
    'message' => 'Jede Nachricht vom System, die dem Benutzer angezeigt werden soll.'
  },
  'order for' => {
    'lastUpdated' => '1240781678',
    'message' => 'Bestellung für'
  },
  'order number' => {
    'lastUpdated' => '1240755850',
    'message' => 'Auftrag-Nr'
  },
  'order status' => {
    'lastUpdated' => '1240756301',
    'message' => 'Status Bestellung'
  },
  'orderNumber' => {
    'lastUpdated' => '1240756317',
    'message' => 'Bestell-Nr'
  },
  'orderStatus' => {
    'lastUpdated' => '1240755942',
    'message' => 'Status dieser Bestellung. (Versandt, Storniert, Lieferrückstand oder Nicht versandt)'
  },
  'organization' => {
    'lastUpdated' => '1228749201',
    'message' => 'Organisation'
  },
  'organization help' => {
    'lastUpdated' => '1241167478',
    'message' => 'Name der Organisation oder Firma, die diese Adresse benutzt, evtl. Ihre Arbeitsstelle.'
  },
  'originatingTransactionId' => {
    'lastUpdated' => '1241159974',
    'message' => 'Wenn die Transaktion eine sich wiederholende Transaktion ist, wird diese die Transaktionnummer der ursprüngliche Transaktion enthalten.'
  },
  'payment address' => {
    'lastUpdated' => '1241615186',
    'message' => 'Rechnungsadresse'
  },
  'payment method' => {
    'lastUpdated' => '1240758494',
    'message' => 'Zahlungsart'
  },
  'payment methods' => {
    'lastUpdated' => '1240758502',
    'message' => 'Zahlungsweise'
  },
  'paymentAddress' => {
    'lastUpdated' => '1241615213',
    'message' => 'Formatierte Zahlungs-/Rechnungsadresse'
  },
  'paymentAddress1' => {
    'lastUpdated' => '1241158270',
    'message' => '1. Zeile in einer Rechnungsadresse mit mehreren Zeilen'
  },
  'paymentAddress2' => {
    'lastUpdated' => '1241158285',
    'message' => '2. Zeile in einer Rechnungsadresse mit mehreren Zeilen.'
  },
  'paymentAddress3' => {
    'lastUpdated' => '1241158294',
    'message' => '3. Zeile in einer Rechnungsadresse mit mehreren Zeilen.'
  },
  'paymentAddressCity' => {
    'lastUpdated' => '1241158343',
    'message' => 'Ort Rechnungsadresse'
  },
  'paymentAddressCode' => {
    'lastUpdated' => '1241158359',
    'message' => 'Code Rechnungsadresse'
  },
  'paymentAddressCountry' => {
    'lastUpdated' => '1241158372',
    'message' => 'Land Rechnungsadresse'
  },
  'paymentAddressId' => {
    'lastUpdated' => '1241159394',
    'message' => 'ID der Rechnungsadresse für diese Transaktion.'
  },
  'paymentAddressName' => {
    'lastUpdated' => '1241158387',
    'message' => 'Name Rechnungsadresse'
  },
  'paymentAddressPhoneNumber' => {
    'lastUpdated' => '1241158401',
    'message' => 'Telefon Rechnungsadresse'
  },
  'paymentAddressState' => {
    'lastUpdated' => '1241158419',
    'message' => 'Bundesland Rechnungsadresse'
  },
  'paymentOptions help' => {
    'lastUpdated' => '1278345421',
    'message' => 'Eine Auswahlliste die alle konfigurierten Bezahlmöglichkeiten für diese Bestellung enthält.'
  },
  'per item shipping' => {
    'lastUpdated' => '1241298477',
    'message' => 'Einzellieferung'
  },
  'phone number' => {
    'lastUpdated' => '1241615251',
    'message' => 'Telefonnummer'
  },
  'phoneNumber help' => {
    'lastUpdated' => '1241166963',
    'message' => 'Telefonnumer für diese Adresse.'
  },
  'phoneNumberField help' => {
    'lastUpdated' => '1241167385',
    'message' => 'Feld für die Telefonnummer zu dieser Adresse.'
  },
  'posLookupForm' => {
    'lastUpdated' => '1241159466',
    'message' => 'Ein Formular, womit ein Bevollmächtigter ein Benutzer über die Emailadresse suchen kann.'
  },
  'posUserId' => {
    'lastUpdated' => '1241158571',
    'message' => 'Käufer-userId'
  },
  'posUsername' => {
    'lastUpdated' => '1241158587',
    'message' => 'Name Käufer'
  },
  'price' => {
    'lastUpdated' => '1228749212',
    'message' => 'Preis'
  },
  'price help' => {
    'lastUpdated' => '1241167247',
    'message' => 'Artikelpreis, formatiert mit zwei Dezimalstellen.'
  },
  'print' => {
    'lastUpdated' => '1228750205',
    'message' => 'Drucken'
  },
  'products' => {
    'lastUpdated' => '1240496136',
    'message' => 'Produkte'
  },
  'quantity' => {
    'lastUpdated' => '1240755956',
    'message' => 'Menge'
  },
  'quantity help' => {
    'lastUpdated' => '1241167315',
    'message' => 'Gekaufte Menge zu diesem Artikel'
  },
  'quantityField help' => {
    'lastUpdated' => '1241167359',
    'message' => 'Das Feld, wo der Benutzer die gewünschte Liefermenge einträgt.'
  },
  'quarterly' => {
    'lastUpdated' => '1228749224',
    'message' => 'Drei Monate'
  },
  'receipt email template' => {
    'lastUpdated' => '1256112730',
    'message' => 'Template für E-Mailempfang'
  },
  'receipt email template help' => {
    'lastUpdated' => '1256112849',
    'message' => 'Welches Template soll verwandt werden, um die E-Mail zu generieren, die der Nutzer als Empfangsbestätigung seiner Bestellung erhält.'
  },
  'refund' => {
    'lastUpdated' => '1240758373',
    'message' => 'Rückerstattung'
  },
  'registerLink help' => {
    'lastUpdated' => '1278345370',
    'message' => 'Ein Link, mit dem der Benutzer einen Account auf dieser Seite erstellen kann, falls er noch keinen hat. Diese Variable wird nur zur Verfügung gestellt, wenn der aktuelle Benutzer Besucher ist.'
  },
  'remove button' => {
    'lastUpdated' => '1240758225',
    'message' => 'Entfernen'
  },
  'removeBox help' => {
    'lastUpdated' => '1278345292',
    'message' => 'Eine Checkbox um diesen Artikel aus dem Warenkorb zu löschen.'
  },
  'removeButton help' => {
    'lastUpdated' => '1241167089',
    'message' => 'Anklicken dieses Knopfs entfernt den Artikel aus dem Warenkorb.'
  },
  'required minimum order amount' => {
    'lastUpdated' => '1240758251',
    'message' => 'Mindestauftragshöhe'
  },
  'sale notification group' => {
    'lastUpdated' => '1256112868',
    'message' => 'Gruppe für Kaufbenachrichtigungen'
  },
  'sale notification group help' => {
    'lastUpdated' => '1256112886',
    'message' => 'Wer soll über eine neue Transaktion benachrichtigt werden?'
  },
  'sameShippingAsBilling help' => {
    'lastUpdated' => '1278345265',
    'message' => 'Eine Checkbox um dem Warenkorb identische Versand- und Rechnungsadresse zuzuweisen.'
  },
  'saveButton help' => {
    'lastUpdated' => '1240758305',
    'message' => 'Der Standardtext zum Sichern-Knopf'
  },
  'schedule all button' => {
    'lastUpdated' => '1242498494',
    'message' => 'Alle terminieren'
  },
  'scheduled payout amount' => {
    'lastUpdated' => '1242498509',
    'message' => 'Terminiert für Auszahlung'
  },
  'search for email' => {
    'lastUpdated' => '1241159575',
    'message' => 'Suchen nach Emailadresse'
  },
  'select gateway template' => {
    'lastUpdated' => '1257324913',
    'message' => 'Gateway-Template wählen'
  },
  'select gateway template help' => {
    'lastUpdated' => '1257324966',
    'message' => 'Dies ist das Template für den Schritt "Bezahl-Gateway wählen"'
  },
  'ship to button' => {
    'lastUpdated' => '1241158650',
    'message' => 'Versandinfo'
  },
  'shipToButton help' => {
    'lastUpdated' => '1241158710',
    'message' => 'gleich wie chooseShippingButton.
'
  },
  'shippableItemsInCart' => {
    'lastUpdated' => '1273049291',
    'message' => 'Ein boolscher Wert der wahr ist, wenn ein Artikel im Warenkorb Versand benötigt.'
  },
  'shipping' => {
    'lastUpdated' => '1240756038',
    'message' => 'Versand'
  },
  'shipping address' => {
    'lastUpdated' => '1240496261',
    'message' => 'Versandadresse'
  },
  'shipping address1' => {
    'lastUpdated' => '1273650016',
    'message' => 'Bitte geben Sie eine Straße für die Versandadresse an.'
  },
  'shipping amount' => {
    'lastUpdated' => '1240756055',
    'message' => 'Versandmenge'
  },
  'shipping city' => {
    'lastUpdated' => '1273650026',
    'message' => 'Bitte geben Sie einen Ort für die Versandadresse an.'
  },
  'shipping code' => {
    'lastUpdated' => '1273650036',
    'message' => 'Bitte geben Sie eine Postleitzahl für die Versandadresse an.'
  },
  'shipping country' => {
    'lastUpdated' => '1273650046',
    'message' => 'Bitte geben Sie ein Land für die Versandadresse an.'
  },
  'shipping firstName' => {
    'lastUpdated' => '1273650058',
    'message' => 'Bitte geben Sie einen Vornamen für die Versandadresse an.'
  },
  'shipping label' => {
    'lastUpdated' => '1273650069',
    'message' => 'Bitte geben Sie eine Bezeichnung für die Versandadresse an.'
  },
  'shipping lastName' => {
    'lastUpdated' => '1273650081',
    'message' => 'Bitte geben Sie einen Nachnamen für die Versandadresse an.'
  },
  'shipping method' => {
    'lastUpdated' => '1240756093',
    'message' => 'Versandart'
  },
  'shipping methods' => {
    'lastUpdated' => '1241297972',
    'message' => 'Versandart'
  },
  'shipping phoneNumber' => {
    'lastUpdated' => '1273650091',
    'message' => 'Bitte geben Sie eine Telefonnummer für die Versandadresse an.'
  },
  'shipping state' => {
    'lastUpdated' => '1273650108',
    'message' => 'Bitte geben Sie Bundesland/Bezirk für die Versandadresse an.'
  },
  'shippingAddress help' => {
    'lastUpdated' => '1241167020',
    'message' => 'HTML-formatierte Versandadresse'
  },
  'shippingAddress1' => {
    'lastUpdated' => '1240496185',
    'message' => 'Versandadresse 1'
  },
  'shippingAddress2' => {
    'lastUpdated' => '1240496205',
    'message' => 'Versandadresse 2'
  },
  'shippingAddress3' => {
    'lastUpdated' => '1240757994',
    'message' => 'Die dritte Zeile einer Versandadresse'
  },
  'shippingAddressChooser help' => {
    'lastUpdated' => '1278345182',
    'message' => 'Eine Dropdown-Auswahlliste zur Auswahl einer Standardversandadresse für alle Artikel im Warenkorb. Möglichkeit zur Bearbeitung und Ergänzung von Adressen ist vorhanden.'
  },
  'shippingAddressCity' => {
    'lastUpdated' => '1240756142',
    'message' => 'Ort'
  },
  'shippingAddressCode' => {
    'lastUpdated' => '1240756207',
    'message' => 'Plz'
  },
  'shippingAddressCountry' => {
    'lastUpdated' => '1240756214',
    'message' => 'Land'
  },
  'shippingAddressId' => {
    'lastUpdated' => '1240756243',
    'message' => 'ID der Versandadresse dieser Transaction'
  },
  'shippingAddressName' => {
    'lastUpdated' => '1240756257',
    'message' => 'Name'
  },
  'shippingAddressPhoneNumber' => {
    'lastUpdated' => '1241166997',
    'message' => 'Telefonnummer zur Versandadresse'
  },
  'shippingAddressState' => {
    'lastUpdated' => '1241158726',
    'message' => 'Bundesland Versandadresse'
  },
  'shippingDriverId' => {
    'lastUpdated' => '1241167173',
    'message' => 'Der UID für das Versandprogramm für diese Transaktion.'
  },
  'shippingDriverLabel' => {
    'lastUpdated' => '1241159745',
    'message' => 'Die Bezeichung für die Versandart in dieser Transaktion'
  },
  'shippingOptions help' => {
    'lastUpdated' => '1241167127',
    'message' => 'Eine Selektliste mit allen Versandoptionen für diese Bestellung.'
  },
  'shippingPrice help' => {
    'lastUpdated' => '1241167219',
    'message' => 'Versandkosten, formatiert mit zwei Dezimalstellen.'
  },
  'shop' => {
    'lastUpdated' => '1241158739',
    'message' => 'Shop'
  },
  'shop notice' => {
    'lastUpdated' => '1241159557',
    'message' => 'Shop Information'
  },
  'shop settings' => {
    'lastUpdated' => '1241158756',
    'message' => 'Shop-Einstellungen'
  },
  'shopCreditDeduction' => {
    'lastUpdated' => '1241158832',
    'message' => 'Shop-Guthaben, verwendet in dieser Transaktion (unformatiert)'
  },
  'state' => {
    'lastUpdated' => '1241158844',
    'message' => 'Bundesland'
  },
  'state help' => {
    'lastUpdated' => '1241159835',
    'message' => 'Bundesland für diese Adresse'
  },
  'stateField help' => {
    'lastUpdated' => '1241158874',
    'message' => 'Bundesland/Provinz für diese Adresse'
  },
  'status code' => {
    'lastUpdated' => '1241159598',
    'message' => 'Status Code'
  },
  'status message' => {
    'lastUpdated' => '1241614782',
    'message' => 'Statusnachricht'
  },
  'statusCode' => {
    'lastUpdated' => '1241159667',
    'message' => 'Der Statuscode der zurück kam, als die Zahlung angewiesen wurde.'
  },
  'statusMessage' => {
    'lastUpdated' => '1241159806',
    'message' => 'Die ausführliche Statusinformation, die zurück kam, als die Zahlung veranlasst wurde.'
  },
  'submit scheduled payouts button' => {
    'lastUpdated' => '1242498549',
    'message' => 'Terminierte Auszahlungen aktivieren'
  },
  'subtotal' => {
    'lastUpdated' => '1240758162',
    'message' => 'Subtotale'
  },
  'subtotalPrice help' => {
    'lastUpdated' => '1240758189',
    'message' => 'Der Gesamtpreis aller Artikel im Warenkorb'
  },
  'tax' => {
    'lastUpdated' => '1228174791',
    'message' => 'Steuer'
  },
  'tax help' => {
    'lastUpdated' => '1228750492',
    'message' => 'Der Steuerbetrag aller Artikel im Warenkorb'
  },
  'taxes' => {
    'lastUpdated' => '1228749240',
    'message' => 'Steuern'
  },
  'taxes help' => {
    'lastUpdated' => '1228750527',
    'message' => 'Der Steuerbetrag dieser Transaktion, formatiert mit zwei Nachkommastellen.'
  },
  'thank you message' => {
    'lastUpdated' => '1228750567',
    'message' => 'Vielen Dank für Ihren Einkauf. Bitte speichern Sie diesen Beleg.'
  },
  'too many of this item' => {
    'lastUpdated' => '1228750598',
    'message' => 'Sie können nicht so viele %s in ihren Warenkorb legen.'
  },
  'total' => {
    'lastUpdated' => '1228750450',
    'message' => 'Summe'
  },
  'totalItems help' => {
    'lastUpdated' => '1228750623',
    'message' => 'Die Gesamtzahl der Artikel in Ihrem Warenkorb'
  },
  'totalPrice help' => {
    'lastUpdated' => '1228750657',
    'message' => 'Die aktuelle Gesamtsumme Ihres Warenkorbes'
  },
  'tracking number' => {
    'lastUpdated' => '1241615974',
    'message' => 'Tracking-Nr Versand'
  },
  'transaction id' => {
    'lastUpdated' => '1228750680',
    'message' => 'Transaktions-ID'
  },
  'transactionCode' => {
    'lastUpdated' => '1228750735',
    'message' => 'Der Transaktionscode oder die Transaktions-ID, die vom Bezahl-Gateway zugewiesen wurde. Wird nicht von allen Bezahlgateways unterstützt.'
  },
  'transactionId' => {
    'lastUpdated' => '1228750438',
    'message' => 'Der eindeutige Bezeichner für diese Transaktion'
  },
  'transactions' => {
    'lastUpdated' => '1228750379',
    'message' => 'Transaktionen'
  },
  'update' => {
    'lastUpdated' => '1228749254',
    'message' => 'Aktualisieren'
  },
  'update cart button' => {
    'lastUpdated' => '1228750230',
    'message' => 'Warenkorb aktualisieren'
  },
  'updateButton help' => {
    'lastUpdated' => '1228750278',
    'message' => 'Anklicken dieses Buttons speichert Ihre Änderungen des Warenkorbes und kalkuliert die Preise neu.'
  },
  'use same shipping as billing' => {
    'lastUpdated' => '1273054473',
    'message' => 'Versandadresse gleich Rechnungsadresse'
  },
  'use this address' => {
    'lastUpdated' => '1228750289',
    'message' => 'Diese Adresse verwenden'
  },
  'useButton help' => {
    'lastUpdated' => '1228750334',
    'message' => 'Ein Button, mit dem der Benutzer eine existierende Adresse für die Verwandung in einem Formular auswählen kann.'
  },
  'userId' => {
    'lastUpdated' => '1228750362',
    'message' => 'Die Benutzer-ID des Benutzers, der diese Trransaktion ausgeführt hat.'
  },
  'userIsVisitor help' => {
    'lastUpdated' => '1278345076',
    'message' => 'Ein boolscher Wert der wahr ist, falls der aktuelle Benutzer Besucher ist.'
  },
  'username' => {
    'lastUpdated' => '1228749285',
    'message' => 'Benutzer'
  },
  'username help' => {
    'lastUpdated' => '1241298556',
    'message' => 'Der Name des Benutzers, der diese Transaktion ausgeführt hat. Spart eine Benutzernamen-Suche.'
  },
  'vendor id' => {
    'lastUpdated' => '1242498569',
    'message' => 'Verkäufer ID'
  },
  'vendor name' => {
    'lastUpdated' => '1242498579',
    'message' => 'Name'
  },
  'vendor payouts' => {
    'lastUpdated' => '1241297599',
    'message' => 'Auszahlungen Verkäufer'
  },
  'vendors' => {
    'lastUpdated' => '1241297623',
    'message' => 'Verkäufer'
  },
  'view cart' => {
    'lastUpdated' => '1228749332',
    'message' => 'Warenkorb ansehen'
  },
  'view my purchases template' => {
    'lastUpdated' => '1228750757',
    'message' => 'Vorlage die meine Einkäufe anzeigt'
  },
  'view my purchases template help' => {
    'lastUpdated' => '1228750801',
    'message' => 'Diese Vorlage zeigt detaillierte Informationen über die Transaktionen des Benutzers an.'
  },
  'viewDetailURL' => {
    'lastUpdated' => '1228750832',
    'message' => 'Ein URL, um detailliertere Informatinoen über die Transaktionen des Benutzers anzuzeigen'
  },
  'viewItemUrl' => {
    'lastUpdated' => '1228750877',
    'message' => 'Ein URL um detailliertere Informationen über diesen Artikel dieser Transaktion anzuzeigen'
  },
  'vp item id' => {
    'lastUpdated' => '1242498600',
    'message' => 'Arikel-Nr'
  },
  'vp item payout amount' => {
    'lastUpdated' => '1242498626',
    'message' => 'Auszahlungsbetrag'
  },
  'vp item payout status' => {
    'lastUpdated' => '1242498649',
    'message' => 'Auszahlungsstatus'
  },
  'vp item price' => {
    'lastUpdated' => '1242498658',
    'message' => 'Preis'
  },
  'vp item quantity' => {
    'lastUpdated' => '1242498671',
    'message' => 'Menge'
  },
  'vp item title' => {
    'lastUpdated' => '1242498687',
    'message' => 'Artikelbezeichnung'
  },
  'vp payouts' => {
    'lastUpdated' => '1257324986',
    'message' => 'Auszahlungen'
  },
  'vp select vendor' => {
    'lastUpdated' => '1257325067',
    'message' => 'Bitte wählen Sie einen Händler aus obiger Liste um individuelle Auszahlungen zu verwalten'
  },
  'vp vendors' => {
    'lastUpdated' => '1257325075',
    'message' => 'Händler'
  },
  'weekly' => {
    'lastUpdated' => '1228749264',
    'message' => 'Woche'
  },
  'who can manage' => {
    'lastUpdated' => '1228750114',
    'message' => 'Wer darf verwalten?'
  },
  'who can manage help' => {
    'lastUpdated' => '1241298577',
    'message' => 'Die Gruppe mit den Verwaltungsrechten im Shop-System.'
  },
  'who is a cashier' => {
    'lastUpdated' => '1240758146',
    'message' => 'Wer ist ein Einkaufsvertreter?'
  },
  'who is a cashier help' => {
    'lastUpdated' => '1241298650',
    'message' => 'Einkaufsvertreter sind berechtigt für andere Benutzer einzukaufen durch Angabe deren Emailadresse in den Warenkorb.'
  },
  'yearly' => {
    'lastUpdated' => '1228749272',
    'message' => 'Jahr'
  }
}
;

1;
